@@ -2,8 +2,6 @@
 #undef NAME_OF_DEV_RANDOM
 #undef NAME_OF_DEV_URANDOM
 #undef HAVE_DEV_RANDOM
-#undef LIBMCRYPT_22
-#undef LIBMCRYPT_VERSION
 #undef NO_GETPASS
 
 #undef PACKAGE
@@ -26,3 +24,8 @@
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
 #undef REQUEST_CAPABILITIES
+
+#undef LIBMCRYPT24
+#undef LIBMCRYPT22
+
+#undef WIN32
