@@ -18,7 +18,7 @@
 
 /* Some functions that didn't fit elsewhere */
 
-/* $Id: extra.c,v 1.4 2000/11/01 18:34:55 nmav Exp $ */
+/* $Id: extra.c,v 1.5 2001/06/04 14:40:56 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -37,7 +37,7 @@
 #include "mcrypt_int.h"
 
 static char rcsid[] =
-    "$Id: extra.c,v 1.4 2000/11/01 18:34:55 nmav Exp $";
+    "$Id: extra.c,v 1.5 2001/06/04 14:40:56 nmav Exp $";
 
 extern int double_check;
 extern char *outfile;
@@ -301,7 +301,7 @@ int write_file_head(FILE * filedes, char *algorithm, char *mode,
 	short int keylen = *keysize;
 	unsigned char null = 0;
 	unsigned char sflag = 0;
-#ifdef LIBMCRYPT_22
+#ifdef LIBMCRYPT22
 	char* index;
 	char algo[70];
 #endif
