@@ -38,11 +38,26 @@
 #include <extra.h>
 #include <xmalloc.h>
 
-#ifndef NO_GETPASS
+
+#ifdef WIN32
+
+#include <conio.h>
+
+char* getpass(char* msg) {
+static char pass[512];
+_cputs(msg);
+_cgets(pass);
+
+return pass;
+
+}
+#else
+
+# ifndef NO_GETPASS
 
 extern int noecho;
 
-static char rcsid[] = "$Id: getpass.c,v 1.1.1.1 2000/05/22 13:09:30 nmav Exp $";
+static char rcsid[] = "$Id: getpass.c,v 1.2 2001/06/04 14:40:56 nmav Exp $";
 
 /* new code, #undef if there are any problems...  */
 #ifdef HAVE_SIGLONGJMP
@@ -277,5 +292,6 @@ char *
 	}
 	return return_value;
 }
+# endif /* NO_GETPASS */
 
-#endif
+#endif /* WIN32 */
