@@ -19,7 +19,7 @@
  */
 
 
-/* $Id: mcrypt.c,v 1.5 2000/12/17 13:14:27 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.6 2001/06/04 14:40:56 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -37,7 +37,7 @@
 
 
 static char rcsid[] =
-    "$Id: mcrypt.c,v 1.5 2000/12/17 13:14:27 nmav Exp $";
+    "$Id: mcrypt.c,v 1.6 2001/06/04 14:40:56 nmav Exp $";
 
 char tmperr[128];
 unsigned int stream_flag = FALSE;
@@ -143,7 +143,7 @@ void usage(void)
 			  "    --help                    prints this help\n"
 			  " -v --version                 prints the version number\n"
 			  "\n"
-			  "Report bugs to mcrypt-dev@argeas.cs-net.gr.\n\n"));
+			  "Report bugs to mcrypt-dev@lists.hellug.gr.\n\n"));
 }
 
 void mcrypt_license()
@@ -183,7 +183,7 @@ int check_hash_algo(char *chain)
 }
 
 
-#ifdef LIBMCRYPT_22
+#ifdef LIBMCRYPT22
 int check_algo(char *chain)
 {
 	int i;
@@ -221,6 +221,14 @@ int check_mode(char *chain)
 }
 #endif
 
+#ifndef LIBMCRYPT_VERSION
+# ifdef LIBMCRYPT24
+#  define LIBMCRYPT_VERSION "2.4"
+# else
+#  define LIBMCRYPT_VERSION "2.2"
+# endif
+#endif
+
 void mcrypt_version()
 {
 
@@ -242,7 +250,7 @@ int main(int argc, char **argv)
 	char *einfile = 0, *dinfile = 0, *keyword = 0;
 	char **file, **keyfile = NULL, *cfile;
 	int x, y, i, file_count = 0, keys = 0, used_algo = FALSE;
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	int *siz;
 #endif
 	gaainfo info;
@@ -366,7 +374,7 @@ int main(int argc, char **argv)
 	double_check = info.double_check;
 	flush = info.flush;
 	nodelete = info.nodelete;
-#ifdef LIBMCRYPT_22
+#ifdef LIBMCRYPT22
 	keysize = 0;
 #else
 	keysize = info.keysize;
@@ -440,7 +448,7 @@ int main(int argc, char **argv)
 		algorithm = mcrypt_malloc(strlen(info.algorithm) + 1);
 		strcpy(algorithm, info.algorithm);
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 
 		i = mcrypt_module_is_block_algorithm(algorithm, algorithms_directory);
 
@@ -489,7 +497,7 @@ int main(int argc, char **argv)
 	}
 
 	if (info.mode != NULL) {
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 		y = mcrypt_module_is_block_algorithm_mode(mode, modes_directory);
 		if (y < 0) {
 			fprintf(stderr, _("Error in mode '%s'.\n"), mode);
@@ -504,7 +512,7 @@ int main(int argc, char **argv)
 #endif
 	}
 
-#ifdef LIBMCRYPT_22
+#ifdef LIBMCRYPT22
 
 	i = check_algo(algorithm);
 	i = keysize = mcrypt_get_key_size(i);
@@ -512,7 +520,7 @@ int main(int argc, char **argv)
 #endif
 
 	if (info.keysize != 0) {
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 		if (info.keysize > mcrypt_module_get_algo_key_size(algorithm, algorithms_directory)) {
 			err_quit(_("The specified key size is too large for this algorithm.\n"));
 		}
@@ -878,7 +886,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 	int full_blocks = 0, rest_blocks = 0;
 	char *fcrc32 = NULL;
 	word32 *keyword;
-#ifdef LIBMCRYPT_22
+#ifdef LIBMCRYPT22
 	int algo, _mode;
 #else
 	int tc;
@@ -900,7 +908,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 	word8 *ciphertext, *ciphertext_pad = NULL;
 	FILE *TOF = NULL;
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	td =
 	    mcrypt_module_open(algorithm, algorithms_directory, mode,
 			       modes_directory);
@@ -919,7 +927,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 
 #endif
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	if (keysize == 0)
 		keysize = mcrypt_enc_get_key_size(td);
 
@@ -949,7 +957,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 			}
 		}
 	}
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	IV = secure_mcrypt_malloc(mcrypt_enc_get_iv_size(td));
 /* Random number generator */
 	for (i = 0; i < mcrypt_enc_get_iv_size(td) / sizeof(word32); i++) {
@@ -1059,7 +1067,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 		write_file_head(TOF, algorithm, mode, keymode, &keysize,
 				salt, salt_size);
 	}
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	if (mcrypt_enc_mode_has_iv(td) == 1 && noiv == FALSE) {
 		write_iv(TOF, IV, mcrypt_enc_get_iv_size(td));
 	}
@@ -1099,7 +1107,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 
 
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	tc = mcrypt_generic_init(td, keyword, len, IV);
 	if (tc < 0) {
 		mcrypt_perror(tc);
@@ -1130,7 +1138,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 			if (bare_flag == FALSE)
 				mhash(tm, ciphertext, how);
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 			if (mcrypt_enc_is_block_mode(td) == 1) {
 #else
 			if (mcrypt_is_block_mode(_mode) == 1) {
@@ -1180,7 +1188,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 		    make_mult(rest_blocks + hash_size + 1, blocksize);
 
 		/* in case of a stream cipher no padding is needed */
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 		if (mcrypt_enc_is_block_mode(td) == 0) {
 #else
 		if (mcrypt_is_block_mode(_mode) == 0) {
@@ -1189,7 +1197,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 		}
 	} else {		/* bare_flag==TRUE */
 		pad_size = blocksize;
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 		if (mcrypt_enc_is_block_mode(td) == 0) {
 #else
 		if (mcrypt_is_block_mode(_mode) == 0) {
@@ -1201,7 +1209,7 @@ encrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 	if (pad_size > 0)
 		ciphertext_pad = mcrypt_malloc(pad_size);
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	if (mcrypt_enc_is_block_mode(td) == 1) {
 #else
 	if (mcrypt_is_block_mode(_mode) == 1) {
@@ -1304,7 +1312,7 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 	char local_salt[100];
 	unsigned int len = 0;
 	int hash_size, pad_size;
-#ifdef LIBMCRYPT_22
+#ifdef LIBMCRYPT22
 	int algo, _mode;
 #else
 	int j;
@@ -1363,7 +1371,7 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 
 	hash_size = mhash_get_block_size(hash_algorithm);
 
-#ifdef LIBMCRYPT_22
+#ifdef LIBMCRYPT22
 	algo = check_algo(algorithm);
 	_mode = check_mode(mode);
 	if (algo < 0 || _mode < 0) {
@@ -1425,7 +1433,7 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 		return 1;
 	}
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	if (mcrypt_enc_mode_has_iv(td) == 1) {
 		if (noiv == FALSE) {
 			IV = read_iv(FROMF, mcrypt_enc_get_iv_size(td));
@@ -1455,7 +1463,7 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 #endif
 
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	j = mcrypt_generic_init(td, keyword, len, IV);
 	if (j < 0) {
 		mcrypt_perror(j);
@@ -1482,7 +1490,7 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 		pad_size = make_mult(blocksize + hash_size, blocksize);
 
 		/* in case of a stream cipher no padding is needed */
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 		if (mcrypt_enc_is_block_mode(td) == 0) {
 #else
                 if (mcrypt_is_block_mode(_mode) == 0) {
@@ -1496,7 +1504,7 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 		ciphertext_p_old = NULL;
 	}
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 	if (mcrypt_enc_is_block_mode(td) == 1) {
 #else
 	if (mcrypt_is_block_mode(_mode) == 1) {
@@ -1829,7 +1837,7 @@ decrypt_general(char *algorithm, char *fromfile, char *tofile, char *key)
 
 	if (bare_flag == FALSE) {
 		newcrc32 = mhash_end(tm);
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 		if (mcrypt_enc_is_block_mode(td) == 1) {
 #else
                 if (mcrypt_is_block_mode(_mode) == 1) {
@@ -1917,7 +1925,7 @@ void rol_buf(void *buffer, int buffersize, void *value)
 	buf[buffersize - 1] = val[0];
 }
 
-#ifndef LIBMCRYPT_22
+#ifndef LIBMCRYPT22
 int print_list(void)
 {
 	MCRYPT td;
